#
# spec file for package minetest
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define minetestuser %{name}
%define minetestgroup %{name}
%if 0%{?suse_version} >= 1500 || (0%{?sle_version} > 120100 && 0%{?is_opensuse})
%bcond_without leveldb
%bcond_without redis
%bcond_without postgresql
%else
%bcond_with leveldb
%bcond_with redis
%bcond_with postgresql
%endif
Name:           minetest
Version:        0.4.17.1
Release:        2.3.1
Summary:        A InfiniMiner/Minecraft inspired game
License:        LGPL-2.1-or-later AND CC-BY-SA-3.0
Group:          Amusements/Games/3D/Simulation
URL:            https://minetest.net/
Source:         https://github.com/minetest/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        minetest-rpmlintrc
Source2:        minetest@.service
# PATCH-FEATURE-OPENSUSE shared_mods.patch -- Search also /usr/share/minetest for mods
Patch0:         shared_mods.patch
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  gmp-devel
BuildRequires:  google-arimo-fonts
BuildRequires:  google-cousine-fonts
BuildRequires:  google-droid-fonts
BuildRequires:  hicolor-icon-theme
BuildRequires:  irrlicht-devel
BuildRequires:  libjpeg-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(luajit)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
Requires:       %{name}-data = %{version}
Requires:       opengl-games-utils
Recommends:     %{name}-lang
Recommends:     minetest-game
%if %{with leveldb}
BuildRequires:  leveldb-devel
%endif
%if %{with redis}
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(hiredis)
%else
# Workaraund a bug in hiredis dependencies.
BuildRequires:  hiredis-devel
%if 0%{?suse_version} <= 1320 && 0%{?sle_version} < 120000
BuildRequires:  libhiredis0_10
%endif
%endif
%endif
%if %{with postgresql}
BuildRequires:  postgresql-devel
%endif

%description
An infinite-world block sandbox game and a game engine, inspired by
InfiniMiner, Minecraft and the like.

%lang_package

%package -n %{name}server
Summary:        Minetest server
License:        LGPL-2.1-or-later
Group:          Amusements/Games/3D/Simulation
Requires:       %{name}-data = %{version}
Requires(pre):  shadow
Recommends:     minetest-game
%{?systemd_requires}

%description -n %{name}server
An infinite-world block sandbox game and a game engine, inspired by
InfiniMiner, Minecraft and the like.

This package contains a minetest server.

%package data
Summary:        Minetest shared data
License:        LGPL-2.1-or-later AND CC-BY-SA-3.0
Group:          Amusements/Games/3D/Simulation
Requires:       google-arimo-fonts
Requires:       google-cousine-fonts
Requires:       google-droid-fonts
BuildArch:      noarch

%description data
An infinite-world block sandbox game and a game engine, inspired by
InfiniMiner, Minecraft and the like.

This package contains data for minetest and minetestserver.

%prep
%setup -q
%patch0 -p1

# Purge bundled jsoncpp and lua.
rm -rf src/json src/lua src/gmp

%build
%cmake \
  -DCUSTOM_DOCDIR="%{_docdir}/%{name}" \
  -DCUSTOM_LOCALEDIR="%{_datadir}/locale" \
  -DCUSTOM_SHAREDIR="%{_datadir}/%{name}" \
  -DBUILD_SERVER=ON \
  -DRUN_IN_PLACE=OFF \
  -DENABLE_GETTEXT=ON \
  -DENABLE_FREETYPE=ON \
  -DENABLE_SYSTEM_JSONCPP=ON \
  -DPNG_PNG_INCLUDE_DIR=$(pkg-config libpng --variable=includedir) \
%if %{with leveldb}
  -DENABLE_LEVELDB=ON \
%else
  -DENABLE_LEVELDB=OFF \
%endif
%if %{with redis}
  -DENABLE_REDIS=ON \
%else
  -DENABLE_REDIS=OFF \
%endif
%if %{with postgresql}
  -DENABLE_POSTGRESQL=ON
%else
  -DENABLE_POSTGRESQL=OFF
%endif
make %{?_smp_mflags} V=1

%install
%cmake_install

# Install the wrapper.
ln -s opengl-game-wrapper.sh %{buildroot}%{_bindir}/%{name}-wrapper
sed -i 's/^Exec=.*$/Exec=%{name}-wrapper/' \
  %{buildroot}%{_datadir}/applications/net.minetest.minetest.desktop
%suse_update_desktop_file -r net.minetest.minetest Game Simulation

# Replace fonts with symlinks (we use the system ones).
for font in Arimo-Regular Cousine-Regular DroidSansFallbackFull; do
    rm %{buildroot}%{_datadir}/%{name}/fonts/$font.ttf
    ln -s %{_datadir}/fonts/truetype/$font.ttf \
      %{buildroot}%{_datadir}/%{name}/fonts/$font.ttf
done

# Clean up.
rm %{buildroot}%{_datadir}/minetest/client/serverlist/.gitignore
%fdupes %{buildroot}%{_datadir}/

install -Dpm 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}@.service
install -Dpm 0644 minetest.conf.example \
  %{buildroot}%{_sysconfdir}/%{name}/minetest.conf.example

mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/

%find_lang %{name}

%post
desktop-file-validate %{_datadir}/applications/net.minetest.minetest.desktop
%if 0%{?suse_version} < 1500
%desktop_database_post
%icon_theme_cache_post
%endif

%if 0%{?suse_version} < 1500
%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%pre -n %{name}server
getent group %{name} > /dev/null || %{_sbindir}/groupadd -r %{minetestgroup}
getent passwd %{name} > /dev/null || \
  %{_sbindir}/useradd -r -g %{minetestgroup} -d %{_localstatedir}/lib/%{name} \
  -s /sbin/nologin -c "user for %{name}server" %{minetestuser}
%service_add_pre %{name}@.service

%post -n %{name}server
%service_add_post %{name}@.service

%preun -n %{name}server
%service_del_preun %{name}@.service

%postun -n %{name}server
%service_del_postun %{name}@.service

%files
%{_bindir}/%{name}
%{_bindir}/%{name}-wrapper
%{_datadir}/applications/net.minetest.minetest.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/*%{name}.appdata.xml
%{_mandir}/man6/%{name}.6%{?ext_man}

%files lang -f %{name}.lang

%files -n %{name}server
%{_bindir}/%{name}server
%attr(0755,%{minetestuser},%{minetestgroup}) %{_localstatedir}/lib/%{name}/
%{_mandir}/man6/%{name}server.6%{?ext_man}
%dir %{_sysconfdir}/%{name}
%config %{_sysconfdir}/%{name}/minetest.conf.example
%{_unitdir}/%{name}@.service

%files data
%doc CONTRIBUTING.md README.txt
%doc %{_docdir}/%{name}/
%{_datadir}/%{name}/

%changelog
* Tue Aug  7 2018 sor.alexei@meowr.ru
- Update to version 0.4.17.1:
  * Fix boo#1103904
  * Fix crash caused by log_deprecated
    and the use of deprecated functions
  * Fix crash on pause menu when pressing up/down keys
- Remove use-pkg-config-to-find-luajit.patch: fixed upstream.
- Update to version 0.4.17:
  * Dungeons: Mostly fix missing stair nodes
  * Cavegen: Fix variable typo that broke mgvalleys large cave
    distribution
  * Prevent translating empty strings
  * upright_sprite: Fix texture position for players
  * core.rotate_node: Do not trigger after_place_node for mod
    compatibility
  * Generate Notifier: Clear events once after all
    'on generated' functions
  * Fix liquid post effect colour behaviour in third person view
  * Delete world dialog: Move buttons to avoid
    double click deletion
  * Fix /shutdown countdown parameter
  * Check argument types inside MetaDataRef Lua API
  * dropped items and falling nodes: Delete in 'ignore' nodes
  * Fix off-by-one in log output line length
  * Fix buffer parameter not working in getMapSlice()
  * Fix rounding error in g/set_node caused by truncation to float
  * Fix dancing text in text input fields
  * Fix undefined behaviour on getting pointer to data in
    empty vector
  * Fix wrong scrolling in text areas
  * Damage: Remove damage ignore timer due to abuse potential
  * Ensure no item stack is being held before crafting
  * Several documentation additions, improvements
  * core.rotate_node: Run callbacks like with any
    regular placed node
  * Biome dust node: Only place on 'walkable' cubic
    non-liquid drawtypes
  * Fix issue Minetest crash when custom font path is not exist
  * Fix Settings tab formspec alignment
  * Do not scale texture unless necessary
  * Fix day_night_ratio_do_override not being initialised
    server-side
  * Fix default item callbacks to work with nil users
  * Prevent from crafting non-existent, unknown items
  * Profiler: Fix var args not being passed to
    callback register function
  * Fix attached particle spawners far from spawn
  * Localplayer: Fix disable_jump effect and standing node position
  * Fix blocks written by vmanip not being marked as modified
  * Fix Rotate Node Placement
  * ServerEnv: Clean up object lifecycle handling
  * Fix the core.wrap_text function
  * Fix empty legacy meta being persisted
  * Statbars: fix incorrect half-images in non-standard
    orientations
  * serialize: use a temporary for SerializeException
  * Fix player coordinate rounding in collisionMoveSimple()
  * Fix for empty key/value when reading item string with
    wear but no metadata
  * Fix render order of overlays
  * Fix console resize issue when maximising game window
  * Fix console not being properly resized after
    window size changed
  * Verify HudSetParams input when hotbar textures are set
  * (Re)spawn players within 'mapgen_limit'
  * Fix sending color codes to clients that don't support them
* Fri Mar  9 2018 werner@suse.de
- Use latest libpng
* Fri Mar  9 2018 werner@suse.de
- Use pkg-config information to set PNG_PNG_INCLUDE_DIR for cmake
* Tue Jan 23 2018 opensuse@trummer.xyz
- Added PostgreSQL database backend
* Mon Jan 22 2018 opensuse@trummer.xyz
- Recommend minetest-game to make server package more useful by default
* Mon Jun  5 2017 sor.alexei@meowr.ru
- Update to version 0.4.16:
  * Add 2D sheet animations for nodes ''(sfan5)''
  * Drop client side chat prediction. No more messages shown to chat
    when you talk and you are disconnected. ''(red-001)''
  * Add particle animation, glow ''(sfan5)
  * Server list: add ping indicators ''(kilbith)''
  * Server side occlusion culling ''(lhofhansl)''
  * New custom progress bar (you can customize it with texture packs)
    (kilbith)
  * Implement delayed shutdown for server owners: /shutdown 60 =>
    shutdowns in 1 min /shutdown -1 cancels it
  * Add support for requesting a reconnect and changing the shutdown
    message to /shutdown
  * Add a mapblock cache in MeshUpdateQueue to improve client rendering
    performance ''(celeron55)''
  * Player data can now be into database. This is an important change,
    players to files are always supported for this release but deprecated.
    Files backend for players will be removed in a future release. See
    http://wiki.minetest.net/Database_backends for compat matrix and
    migration steps.
  * Sounds: add fading sounds
  * Save automatically window size when modified. This behaviour can
    be disabled in client settings
  * Add cancel button to password change formspec
  * Improve pause menu with more user friendly informations and update
    keys dynamicly depending on your configuration
  * Merge singleplayer & server tab on desktop clients
  * Add /clearinv chat command
  * Add keyword-based search to server-list and advance settings
  * Add hardware-based itemstacks and node coloring
  * Undersampling which should make minetest run better on low end devices
  * Full changelog see http://dev.minetest.net/Changelog#0.4.15_.E2.86.92_0.4.16
- Minor spec cleanup.
* Thu Jan  5 2017 khyota@redhyena.net
- Add use-pkg-config-to-find-luajit.patch https://github.com/minetest/minetest/issues/4483
* Mon Dec 26 2016 mailaender@opensuse.org
- Update to 0.4.15
* Wed Jul 27 2016 rpm@fthiessen.de
- Replace fonts by system ones.
- Fixed license.
* Mon May 16 2016 rpm@fthiessen.de
- Update to 0.4.14
- Removed upstream fixed fix-cguittfont.patch,
  i18n.patch and fix-find-luajit.patch
* Wed Dec  2 2015 rpm@fthiessen.de
- Added fix-cguittfont.patch to fix missing library "libcguittfont".
* Tue Nov 24 2015 rpm@fthiessen.de
- Update to 0.4.13:
  * Added: fix-find-luajit.patch to detect systems luajit correctly
  * Removed upstream fixed FindJson.cmake.patch and
    minetest-0.4.8-shared-irrlicht.patch
* Sun Apr 12 2015 adam@mizerski.pl
- Cleaned up spec file
  - Used spec-cleaner
  - sorted and revised BuildRequires
  - removed all "%%if 0%%{?suse_version}" - there's too many openSUSE
    specific things to keep it really multi-distro.
- Splitted compilation of minetest and minetestserver
  (idea borrowed from ArchLinux)
  - Splitted minetest package into minetest, minetestserver and
    minetest-data.
- Enabled support for translations.
  - Added minetest-lang subpackage.
- Enabled support for redis and leveldb to minetestsever
- Fixed support for opengl-game-wrapper.sh
- Made minetest use system jsoncpp and lua instead of bundled ones.
- Added files:
  - minetest@.service
  - minetest-rpmlintrc
  - supress warning aboud desktop file pointing to minetest-wrapper
- Added patches:
  - FindJson.cmake.patch - copied from Debian.
  - i18n.patch - copied from Debian.
  - minetest-0.4.8-shared-irrlicht.patch - copied from Fedora.
  - shared_mods.patch - copied from Debian and modified.
- Added "minetest" user and group for minetestserver.
* Thu Feb 19 2015 khyota@redhyena.net
- update to 0.4.12
* Wed Jan  7 2015 ejobling248@gmail.com
- update to 0.4.11
* Thu Nov 27 2014 khyota@redhyena.net
- update title and description
* Tue Jan  7 2014 mailaender@opensuse.org
- update to 0.4.9
- use simpler GitHub release https://en.opensuse.org/SourceUrls
* Thu Aug  8 2013 opensuse@dstoecker.de
- update to 0.4.7
* Fri Apr 12 2013 mailaender@opensuse.org
- update to version 0.4.6
* Sun Dec  9 2012 m407@mail.ru
- Build version 0.4.4
* Thu Sep 20 2012 joop.boonen@opensuse.org
- Build version 0.4.3
* Wed May 16 2012 joop.boonen@opensuse.org
- Created gcc 4.7 patch
* Sat Nov 26 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Sat Nov 26 2011 PVince81@opensuse.org
- Fixed package to compile with irrlicht 1.7.9
- Updated spec file to match game packaging guidelines
* Thu Nov 10 2011 giacomosrv@gmail.com
- packaged minetest version 0.3.1
* Tue Nov  1 2011 giacomosrv@gmail.com
- packaged minetest version 0.3.0
* Sun Oct 16 2011 giacomosrv@gmail.com
- packaged minetest version 0.2.20110922_3
* Sat Sep 24 2011 giacomosrv@gmail.com
- packaged minetest version 0.2.20110922_1
* Wed Aug 17 2011 giacomosrv@gmail.com
- packaged minetest version 0.2.20110731_3
